@@ -1,5 +1,7 @@
-__version__ = '0.6.9'
+__version__ = '0.7.1'
 __metafeature_version__ = '0.4.6'
 __metafeature_path__ = 'd3m.primitives.metalearning.metafeature_extractor.BYU'
 __imputer_version__ = '0.2.2'
 __imputer_path__ = 'd3m.primitives.data_preprocessing.random_sampling_imputer.BYU'
+__profiler_version__ = '0.0.1'
+__profiler_path__ = 'd3m.primitives.schema_discovery.profiler.BYU'
\ No newline at end of file
